summaryrefslogtreecommitdiffstats
path: root/kverbos/kverbos/kfeedercontrol.h
diff options
context:
space:
mode:
Diffstat (limited to 'kverbos/kverbos/kfeedercontrol.h')
-rw-r--r--kverbos/kverbos/kfeedercontrol.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kverbos/kverbos/kfeedercontrol.h b/kverbos/kverbos/kfeedercontrol.h
index 635a6311..79a02cc0 100644
--- a/kverbos/kverbos/kfeedercontrol.h
+++ b/kverbos/kverbos/kfeedercontrol.h
@@ -39,14 +39,14 @@ public:
bool addOne();
/** sends n points to the KFeeder */
bool addN(int n);
/** returns if the KProcess is still active. This is useful right after the start to
* see if it was successful
*/
bool isActive() { return active; }
/** returns the last result of the latest dcop operation */
bool getLastResult() { return lastResult; }
private:
- KProcess childFeeder;
+ TDEProcess childFeeder;
TQCString feederID;
bool active;
bool lastResult;
@@ -39,14 +39,14 @@ public:
/** sends n points to the KFeeder */
bool addN(int n);
- /** returns if the KProcess is still active. This is useful right after the start to
+ /** returns if the TDEProcess is still active. This is useful right after the start to
* see if it was successful
*/